@@ -25,7 +25,7 @@ import bitcoin.signature
 import bitcoin.core.script
 
 _ssl = ctypes.cdll.LoadLibrary(
-    ctypes.util.find_library('ssl.35') or ctypes.util.find_library('ssl') or 'libeay32'
+    ctypes.util.find_library('ssl.35') or ctypes.util.find_library('ssl') or ctypes.util.find_library('libeay32')
 )
 
 _libsecp256k1_path = ctypes.util.find_library('secp256k1')
@@ -257,6 +257,8 @@ class CECKey:
         self.k = None
 
     def set_secretbytes(self, secret):
+        if(len(secret) != 32):
+            raise ValueError("Secret bytes must be exactly 32 bytes")
         priv_key = _ssl.BN_bin2bn(secret, 32, None)
         group = _ssl.EC_KEY_get0_group(self.k)
         pub_key = _ssl.EC_POINT_new(group)
@@ -432,6 +434,12 @@ class CECKey:
         norm_sig = ctypes.c_void_p(0)
         _ssl.d2i_ECDSA_SIG(ctypes.byref(norm_sig), ctypes.byref(ctypes.c_char_p(sig)), len(sig))
 
+        # Newer versions of OpenSSL (>3.0.0?) seem to fail here, leaving a null
+        # pointer in norm_sig
+        if not norm_sig:
+            return False
+
+        # Older versions (<3.0.0?) seem to fail here, with a empty derlen
         derlen = _ssl.i2d_ECDSA_SIG(norm_sig, 0)
         if derlen == 0:
             _ssl.ECDSA_SIG_free(norm_sig)
