@@ -13,11 +13,6 @@
 
 """Make a boostrap.dat file by getting the blocks from the RPC interface."""
 
-import sys
-if sys.version_info.major < 3:
-    sys.stderr.write('Sorry, Python 3.x required by this example.\n')
-    sys.exit(1)
-
 import bitcoin
 import bitcoin.rpc
 
@@ -34,7 +29,7 @@ try:
     if len(sys.argv) == 3:
         bitcoin.SelectParams(sys.argv[2])
 except Exception as ex:
-    print('Usage: %s <block-height> [network=(mainnet|testnet|regtest)] > bootstrap.dat' % sys.argv[0], file=sys.stderr)
+    print('Usage: %s <block-height> [network=(mainnet|testnet|regtest|signet)] > bootstrap.dat' % sys.argv[0], file=sys.stderr)
     sys.exit(1)
 
 
