@@ -13,11 +13,6 @@
 
 """Serialize some bitcoin datastructures and show them in serialized and repr form."""
 
-import sys
-if sys.version_info.major < 3:
-    sys.stderr.write('Sorry, Python 3.x required by this example.\n')
-    sys.exit(1)
-
 from bitcoin import SelectParams
 from bitcoin.messages import msg_version, msg_tx, msg_block
 
